we-build.city
=============

We-build.city is a collaboration platform designed to enable everyone to participate in urban planning more easily. It encourages citizens, companies, public authorities and any other stakeholder to engage and cooperate in the urban planning process in order to reduce frustration, and possible lengthy and costly conflicts which often arise.
